@@ -344,6 +344,15 @@ impl Args {
                     self.job_specs = job_specs;
                     updated = true;
                 }
+                match mode {
+                    Mode::Run | Mode::Solve | Mode::Study => {
+                        if self.job_specs.len() == 0 {
+                            error!("{:?} requires job specs", &mode);
+                            exit(1);
+                        }
+                    }
+                    _ => {}
+                }
             }
             Err(e) => {
                 error!("{}", &e);
